// express: É um framework web para Node.js que simplifica a criação de servidores HTTP.
// body-parser: Middleware para interpretar o corpo das requisições HTTP. Ele permite que você use req.body para acessar o corpo da requisição.
// db: É um módulo que, supostamente, permite conectar-se e interagir com um banco de dados. Ele deve estar definido no arquivo db.js em sua estrutura de projeto.

const express = require('express');
const bodyParser = require('body-parser');
const db = require('./db');

//Aqui, criamos uma instância do servidor express e configuramos o body-parser para interpretar corpos de requisição em JSON e também em formato x-www-form-urlencoded (normalmente usado em formulários web tradicionais).
const app = express();
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({ extended: true }));

// Create (Criação)
app.post('/usuario', (req, res) => {
    const { nome, email } = req.body;
    const query = 'INSERT INTO usuarios (nome, email) VALUES (?, ?)';
    db.query(query, [nome, email], (err, results) => {
        if(err) throw err;
        res.send('Usuário adicionado com sucesso!');
    });
});

// Read (Leitura)
app.get('/usuarios', (req, res) => {
    db.query('SELECT * FROM usuarios', (err, rows) => {
        if(err) throw err;
        res.json(rows);
    });
});

// Update (Atualização)
app.put('/usuario/:id', (req, res) => {
    const { nome, email } = req.body;
    const query = 'UPDATE usuarios SET nome = ?, email = ? WHERE id = ?';
    db.query(query, [nome, email, req.params.id], (err, results) => {
        if(err) throw err;
        res.send('Usuário atualizado com sucesso!');
    });
});

// Delete (Exclusão)
app.delete('/usuario/:id', (req, res) => {
    const query = 'DELETE FROM usuarios WHERE id = ?';
    db.query(query, [req.params.id], (err, results) => {
        if(err) throw err;
        res.send('Usuário excluído com sucesso!');
    });
});


// Como devemos configurar a porta para funcionar na Integrator Host
const PORT = process.env.PORT //aqui será a porta que o PM2 irá colocar
//const PORT = 3000;

app.listen(PORT, () => {
    console.log(`Server is running on port ${PORT}`);
});
